@@ -4,8 +4,7 @@ class NewsTimes(BasicNewsRecipe):
     title                 = 'Newstimes'
     __author__            = 'Darko Miletic'
     description           = 'news from USA'
-    language = 'en'
-
+    language              = _('English')
     oldest_article        = 1
     max_articles_per_feed = 100
     no_stylesheets        = True
